const axios = require('axios');
const MAX_SMS = 54  // Maximum SMS text message character length
// White list of allowed phone numbers (all other numbers blocked)
const WHITELIST = new Set(['+15555550100','+15555550199']);

exports.handler = async (context, event, callback) => {
  // Create a new message response object
  const twiml = new Twilio.twiml.MessagingResponse();

  // REST API base URL and any custom headers
  const instance = axios.create({
    baseURL: 'https://io.adafruit.com/api/v2/webhooks/feed/',
    headers: { 'X-Custom-Header': 'Twilio' },
  });

  try {
    // Verify valid sender against whitelist
    if(!WHITELIST.has(event.From)){
      return callback(new Error("Unauthorized sender"));
    }

    // Validate message length
    if(event.Body.length > MAX_SMS){
      twiml.message(`Message too long by ${event.Body.length - MAX_SMS} characters!  (Maximum ${MAX_SMS})⛔`);
      return callback(null, twiml);
    }

    const update = await instance.post('/ZTZpiFM4Eh7dNfv4zqzYzUmjBRnd/', {
      value: event.Body
    }).catch(function (error) {
      // Catch post failure and notify sender
      twiml.message(`Something went wrong! ⛔`);
      return callback(null, twiml);
    });

    // Add a message to the response to let the user know that everything worked
    twiml.message(
      `Message received. ☘️`
    );

    return callback(null, twiml);
  } catch (error) {
    // As always with async functions, you need to be sure to handle errors
    console.error(error);
    return callback(error);
  }
};